#ifndef _GNOME_PRINT_PERL_H_
#define _GNOME_PRINT_PERL_H_

#include <gtk2perl.h>

/* basic include files */
#include <libgnomeprint/gnome-font.h>
#include <libgnomeprint/gnome-font-face.h>
#include <libgnomeprint/gnome-glyphlist.h>
#include <libgnomeprint/gnome-print.h>
#include <libgnomeprint/gnome-print-config.h>
#include <libgnomeprint/gnome-print-job.h>

#include <libgnomeprintui/gnome-font-dialog.h>
#include <libgnomeprintui/gnome-print-dialog.h>
#include <libgnomeprintui/gnome-print-job-preview.h>
#include <libgnomeprintui/gnome-print-preview.h>
#include <libgnomeprintui/gnome-print-paper-selector.h>
#include <libgnomeprintui/gnome-print-unit-selector.h>

#include "gnomeprintperl-autogen.h"
#include "gnomeprintperl-version.h"

#endif /* _GNOME_PRINT_PERL_H_ */
